@@ -139,6 +139,13 @@ sub setup ($) {
 	    DEFAULT => 0,
 	    HELP => 'Build architecture: all packages by default'
 	},
+	'BUILD_ARCH_ANY'			=> {
+	    TYPE => 'BOOL',
+	    VARNAME => 'build_arch_any',
+	    GROUP => 'Build options',
+	    DEFAULT => 1,
+	    HELP => 'Build architecture: any packages by default'
+	},
 	'NOLOG'					=> {
 	    TYPE => 'BOOL',
 	    GROUP => '__INTERNAL',
@@ -796,6 +803,18 @@ sub setup ($) {
 	    DEFAULT => [],
 	    HELP => 'Additional per-build dependencies.  Do not set by hand.'
 	},
+	'MANUAL_DEPENDS_ARCH'			=> {
+	    TYPE => 'ARRAY:STRING',
+	    GROUP => '__INTERNAL',
+	    DEFAULT => [],
+	    HELP => 'Additional per-build dependencies.  Do not set by hand.'
+	},
+	'MANUAL_CONFLICTS_ARCH'			=> {
+	    TYPE => 'ARRAY:STRING',
+	    GROUP => '__INTERNAL',
+	    DEFAULT => [],
+	    HELP => 'Additional per-build dependencies.  Do not set by hand.'
+	},
 	'MANUAL_DEPENDS_INDEP'			=> {
 	    TYPE => 'ARRAY:STRING',
 	    GROUP => '__INTERNAL',
@@ -1027,7 +1046,8 @@ sub setup ($) {
 
 		return $retval;
 	    },
-	    HELP => 'Should the dependency resolver use alternatives in Build-Depends and Build-Depends-Indep?  By default, only the first alternative will be used; all other alternatives will be removed.  Note that this does not include architecture-specific alternatives, which are reduced to the build architecture prior to alternatives removal.  This should be left disabled when building for unstable; it may be useful when building backports.'
+	    EXAMPLE => '$resolve_alternatives = 0;',
+	    HELP => 'Should the dependency resolver use alternatives in Build-Depends, Build-Depends-Arch and Build-Depends-Indep?  By default, using the \'internal\' or \'apt\' resolvers, only the first alternative will be used; all other alternatives will be removed.  When using the \'aptitude\' resolver, it will default to using all alternatives.  Note that this does not include architecture-specific alternatives, which are reduced to the build architecture prior to alternatives removal.  This should be left disabled when building for unstable; it may be useful when building for experimental or backports.  Set to undef to use the default, 1 to enable, or 0 to disable.'
 	},
 	'SBUILD_BUILD_DEPENDS_SECRET_KEY'		=> {
 	    TYPE => 'STRING',
